<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet
xmlns:d="http://docbook.org/ns/docbook"
xmlns:xl="http://www.w3.org/1999/xlink"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
version="1.0">

<!--rst

.. _superbibmany02_xml.xsl:

======================
superbibmany02_xml.xsl
======================

DESCRIPTION
===========

produce one DocBook 5 with a form containing bibliograhy references and general
information of one author/user

this DocBook will be chuncked for html output

TODO
====

EVOLUTIONS
==========

$Id$

- fplod 20110629T135204Z cratos.locean-ipsl.upmc.fr (Linux)

  * authorgroup is found in main.xml

- fplod 2008-09-17T10:40:43Z aedon.locean-ipsl.upmc.fr (Darwin)

  * project name from main.xml file instead of a fixed one

- fplod 2008-04-30T14:52:55Z aedon.locean-ipsl.upmc.fr (Darwin)

  * language inherited from biblio.xml

- fplod 2008-04-30T06:44:31Z aedon.locean-ipsl.upmc.fr (Darwin)

  * chgt for dbk5 in

- fplod 2007-10-17T08:06:40Z aedon.locean-ipsl.upmc.fr (Darwin)

  * improve sort (diacriticals)

- fplod 2007-05-18T14:59:29Z aedon.locean-ipsl.upmc.fr (Darwin)

  * modif gestion id

- fplod 2007-05-16T15:28:56Z aedon.locean-ipsl.upmc.fr (Darwin)

  * correction pour homonymes partiels

- fplod 2007-05-15T15:07:37Z aedon.locean-ipsl.upmc.fr (Darwin)

  * modification to see user/userid="template" information if author_id
    doesn't exit in users datafile

- fplod 2007-04-16T08:10:06Z aedon.locean-ipsl.upmc.fr (Darwin)

  * creation

-->

<xsl:output
 method="xml"
 indent="yes"
 encoding="ISO-8859-1"
 omit-xml-declaration="yes"/>


<xsl:include href="firstname_id.xsl"/>
<xsl:include href="surname_id.xsl"/>
<xsl:include href="table_authors.xsl"/>
<xsl:include href="form_db.xsl"/>

<xsl:variable name="list_author_ids" select="///d:author[not( self::node() = following::d:author )]"/>

<xsl:variable name="project">
 <xsl:value-of select="document('main.xml')//d:keyword[@xml:id='project']"/>
</xsl:variable>

<xsl:template match="d:bibliography">

<xsl:element name="article">
<xsl:attribute name="version">5.0</xsl:attribute>
<xsl:attribute name="xmlns">http://docbook.org/ns/docbook</xsl:attribute>
<xsl:attribute name="xml:lang"><xsl:value-of select="@xml:lang"/></xsl:attribute>
<title><xsl:value-of select="$project"/> - Known users</title>
<info>
<authorgroup>
<xsl:copy-of select="document('main.xml')//d:info/d:authorgroup"/>
</authorgroup>
<keywordset>
<keyword><xsl:value-of select="$project"/></keyword>
</keywordset>
<!-- ++ date -->
</info>
<sect1 xml:id="intro">
<title>Intro</title>
 <xsl:element name="para">
These pages intent to provide an form for every known user of <xsl:value-of select="$project"/> with bibliography and information.
 </xsl:element>
<xsl:element name="para">
   The mail sent by filling these forms will be used to update
<link xl:href="../../one/main.php"><xsl:value-of select="$project"/>-Publications-Papers</link>
and <link xl:href="../../one/user.html"><xsl:value-of select="$project"/> Users</link>.
</xsl:element>

<xsl:call-template name="para_lastupdate_bib">
 <xsl:with-param name="language" select="@xml:lang"/>
 <xsl:with-param name="date" select="d:info/d:date"/>
 <xsl:with-param name="mode" select="'dbk'"/>
</xsl:call-template>

<xsl:call-template name="para_lastupdate_user">
 <xsl:with-param name="language" select="@xml:lang"/>
 <xsl:with-param name="date" select="document('user.xml')/users/date"/>
 <xsl:with-param name="mode" select="'dbk'"/>
</xsl:call-template>

<xsl:call-template name="table_authors">
 <xsl:with-param name="linktype" select="'external'"/>
</xsl:call-template>

</sect1>

<!-- loop on author_ids -->
<xsl:for-each select="$list_author_ids">
 <xsl:sort order="ascending" data-type="text" select="translate(.,'abcdefghijklmnopqrstuvwxyz ', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ_EECAUEONO')"/>
 <xsl:variable name="author_id2">
<xsl:call-template name="surname_id">
 <xsl:with-param name="surname" select="d:personname/d:surname"/>
</xsl:call-template>
<xsl:text>_</xsl:text>
<xsl:call-template name="firstname_id">
 <xsl:with-param name="firstname" select="d:personname/d:firstname"/>
</xsl:call-template>
</xsl:variable>
<!--
<xsl:message terminate="no">
 noeud courant <xsl:value-of select="name(.)"/>
 author <xsl:value-of select="."/>
 author_id2 <xsl:value-of select="$author_id2"/>
</xsl:message>
-->
 <xsl:call-template name="one_author_id">
  <xsl:with-param name="author_id" select="$author_id2"/>
  <xsl:with-param name="author_name" select="."/>
 </xsl:call-template>
</xsl:for-each>

</xsl:element>
</xsl:template>

<xsl:template match="d:info/d:date"/>
<xsl:template match="d:bibliography/d:title"/>

<xsl:template name="one_author_id">
 <xsl:param name="author_id"/>
 <xsl:param name="author_name"/>
 <xsl:element name="sect1">
  <xsl:attribute name="xml:id">
   <xsl:value-of select="$author_id"/>
  </xsl:attribute>
  <xsl:element name="title">
<xsl:value-of select="normalize-space($author_name/d:personname/d:firstname)"/><xsl:text> </xsl:text><xsl:value-of select="normalize-space($author_name/d:personname/d:surname)"/>
  </xsl:element>
  <xsl:element name="para">
   The mail sent by filling this form will be used to update
<link xl:href="../../one/main.php"><xsl:value-of select="$project"/> Publications-Papers</link>
and <link xl:href="../../one/user.html"><xsl:value-of select="$project"/> Users</link>.
  </xsl:element>

  <xsl:choose>
   <xsl:when test="document('user.xml')/users/user[descendant::userid=$author_id]/userid = $author_id">
    <xsl:call-template name="form_db">
     <xsl:with-param name="author_id" select="$author_id"/>
     <xsl:with-param name="user" select="document('user.xml')/users/user[descendant::userid=$author_id]"/>
     <xsl:with-param name="visu_modif" select="'modif'"/>
     <xsl:with-param name="bibmode" select="'yes'"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="form_db">
     <xsl:with-param name="author_id" select="$author_id"/>
     <xsl:with-param name="user" select="document('user.xml')/users/user[descendant::userid='template']"/>
     <xsl:with-param name="visu_modif" select="'modif'"/>
     <xsl:with-param name="bibmode" select="'yes'"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:element>
</xsl:template>

</xsl:stylesheet>
